import { NgModule } from '@angular/core';
import { Route, RouterModule } from '@angular/router';
import { AuthGuard } from './modules/auth/services/auth/auth.guard';
import { NotFoundComponent } from './modules/shared/components/not-found/not-found.component';

interface AppMenuEntry {
    label: string;
    icon: string;
    path?: string;
    matchExact?: boolean;
    level?: number;
}

interface AppRoute extends Route {
    menuEntries?: AppMenuEntry[];
}

export const appRoutes: AppRoute[] = [
    {
        path: 'auth',
        loadChildren: () => import('./modules/auth/auth.module').then(m => m.AuthModule),
    },
    {
        path: '',
        component: NotFoundComponent,
        menuEntries: [
            {
                label: 'MENU.HOME',
                icon: 'fa fa-home',
                matchExact: true,
            },
        ],
        canActivate: [ AuthGuard, ],
        canActivateChild: [ AuthGuard, ],
    },
    {
        path: 'profile',
        loadChildren: () => import('./modules/profile/profile.module').then(m => m.ProfileModule),
        menuEntries: [
            {
                label: 'MENU.PROFILE',
                icon: 'fa fa-user',
            },
        ],
        canActivate: [ AuthGuard, ],
        canActivateChild: [ AuthGuard, ],
    },
    {
        path: 'community',
        component: NotFoundComponent,
        menuEntries: [
            {
                label: 'MENU.COMMUNITY',
                icon: 'fa fa-users',
            },
        ],
        canActivate: [ AuthGuard, ],
        canActivateChild: [ AuthGuard, ],
    },
    {
        path: 'questions',
        component: NotFoundComponent,
        menuEntries: [
            {
                label: 'MENU.QUESTIONS',
                icon: 'fa fa-question',
                level: 1,
            }
        ],
        canActivate: [ AuthGuard, ],
        canActivateChild: [ AuthGuard, ],
    },
    {
        path: 'messages',
        component: NotFoundComponent,
        menuEntries: [
            {
                label: 'MENU.MESSAGES',
                icon: 'fa fa-comments',
            },
        ],
        canActivate: [ AuthGuard, ],
        canActivateChild: [ AuthGuard, ],
    },
    {
        path: 'tests',
        component: NotFoundComponent,
        menuEntries: [
            {
                label: 'MENU.TESTS',
                icon: 'fa fa-heartbeat',
            },
        ],
        canActivate: [ AuthGuard, ],
        canActivateChild: [ AuthGuard, ],
    },
    {
        path: 'research',
        component: NotFoundComponent,
        menuEntries: [
            {
                label: 'MENU.RESEARCH',
                icon: 'fa fa-flask',
            },
        ],
        canActivate: [ AuthGuard, ],
        canActivateChild: [ AuthGuard, ],
    },
    {
        path: 'admin',
        loadChildren: () => import('./modules/admin/admin.module').then(m => m.AdminModule),
        menuEntries: [
            {
                label: 'MENU.ADMIN',
                icon: 'fa fa-id-card',
                matchExact: true,
            },
            {
                path: 'admin/users',
                label: 'MENU.USERS',
                icon: 'fa fa-users',
                level: 1,
            }
        ],
        canActivate: [ AuthGuard, ],
        canActivateChild: [ AuthGuard, ],
    },
];

@NgModule({
    imports: [RouterModule.forRoot(appRoutes)],
    exports: [RouterModule]
})
export class AppRoutingModule { }
